@@ -1,6 +1,6 @@
 # optionsbar_rotate.py
 #
-# Copyright 2018-2021 Romain F. T.
+# Copyright 2018-2022 Romain F. T.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 
 from gi.repository import Gtk
 from .abstract_optionsbar import AbstractOptionsBar
-from .utilities import utilities_add_unit_to_spinbtn
+from .utilities_units import utilities_add_unit_to_spinbtn
 
 class OptionsBarRotate(AbstractOptionsBar):
 	__gtype_name__ = 'OptionsBarRotate'
