@@ -1,8 +1,9 @@
 #!/bin/bash
+# Licensed under GPL3 https://github.com/maoschanz/drawing/blob/master/LICENSE
 
 DISTRO="unstable" # this script is for local use, distros manage this themselves
-PACKAGE_NAME="drawing" # XXX ask it as an input maybe?
-VERSION="0.9.0"
+PACKAGE_NAME="drawing"
+VERSION="1.0.1" # XXX ask it as an input maybe?
 
 function separator () {
 	echo ""
